"use strict";
var core_1 = require('@angular/core');
var forms_1 = require('@angular/forms');
var Quill = require('quill');
// function createMinMaxValidator(minLength: number, maxLength: number, quillEditor: any) {
//   return function validateMinMax(c: FormControl) {
//     let err: {
//           minLengthError?: {given: number, minLength: number};
//           maxLengthError?: {given: number, maxLength: number};
//         } = {},
//         valid = true;
//     const textLength = quillEditor.getText().trim().length;
//     if (minLength) {
//       err.minLengthError = {
//         given: textLength,
//         minLength: minLength
//       };
//       valid = textLength >= minLength;
//     }
//     if (maxLength) {
//       err.maxLengthError = {
//         given: textLength,
//         maxLength: maxLength
//       };
//       valid = textLength < maxLength;
//     }
//     return valid ? null : err;
//   };
// }
var QuillEditorComponent = (function () {
    function QuillEditorComponent(elementRef) {
        this.elementRef = elementRef;
        this.emptyArray = [];
        this.defaultModules = {
            toolbar: [
                ['bold', 'italic', 'underline', 'strike'],
                ['blockquote', 'code-block'],
                [{ 'header': 1 }, { 'header': 2 }],
                [{ 'list': 'ordered' }, { 'list': 'bullet' }],
                [{ 'script': 'sub' }, { 'script': 'super' }],
                [{ 'indent': '-1' }, { 'indent': '+1' }],
                [{ 'direction': 'rtl' }],
                [{ 'size': ['small', false, 'large', 'huge'] }],
                [{ 'header': [1, 2, 3, 4, 5, 6, false] }],
                [{ 'color': this.emptyArray.slice() }, { 'background': this.emptyArray.slice() }],
                [{ 'font': this.emptyArray.slice() }],
                [{ 'align': this.emptyArray.slice() }],
                ['clean'],
                ['link', 'image', 'video'] // link and image, video
            ]
        };
        this.onEditorCreated = new core_1.EventEmitter();
        this.onContentChanged = new core_1.EventEmitter();
        this.onModelChange = function () { };
        this.onModelTouched = function () { };
    }
    QuillEditorComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.editorElem = this.elementRef.nativeElement.children[0];
        this.quillEditor = new Quill(this.editorElem, {
            modules: this.modules || this.defaultModules,
            placeholder: this.placeholder || 'Insert text here ...',
            readOnly: this.readOnly || false,
            theme: this.theme || 'snow',
            formats: this.formats
        });
        //this.validateFn = createMinMaxValidator(this.minLength, this.maxLength, this.quillEditor);
        if (this.content) {
            this.quillEditor.pasteHTML(this.content);
        }
        this.onEditorCreated.emit(this.quillEditor);
        // mark model as touched if editor lost focus
        this.quillEditor.on('selection-change', function (range) {
            if (!range) {
                _this.onModelTouched();
            }
        });
        // update model if text changes
        this.quillEditor.on('text-change', function (delta, oldDelta) {
            var html = _this.editorElem.children[0].innerHTML;
            var text = _this.quillEditor.getText();
            if (html === '<p><br></p>') {
                html = null;
            }
            _this.onModelChange(html);
            _this.onContentChanged.emit({
                editor: _this.quillEditor,
                html: html,
                text: text
            });
        });
    };
    QuillEditorComponent.prototype.ngOnChanges = function (changes) {
        var min;
        var max;
        if (changes['readOnly'] && this.quillEditor) {
            this.quillEditor.enable(!changes['readOnly'].currentValue);
        }
        if (this.quillEditor) {
            if (changes['minLength']) {
                min = changes['minLength'].currentValue;
            }
            if (changes['maxLength']) {
                max = changes['maxLength'].currentValue;
            }
        }
    };
    QuillEditorComponent.prototype.writeValue = function (currentValue) {
        this.content = currentValue;
        if (this.quillEditor) {
            if (currentValue) {
                this.quillEditor.pasteHTML(currentValue);
                return;
            }
            this.quillEditor.setText('');
        }
    };
    QuillEditorComponent.prototype.registerOnChange = function (fn) {
        this.onModelChange = fn;
    };
    QuillEditorComponent.prototype.registerOnTouched = function (fn) {
        this.onModelTouched = fn;
    };
    QuillEditorComponent.prototype.validate = function (c) {
        if (!this.quillEditor) {
            return null;
        }
        var err = {}, valid = true;
        var textLength = this.quillEditor.getText().trim().length;
        if (this.minLength) {
            err.minLengthError = {
                given: textLength,
                minLength: this.minLength
            };
            valid = textLength >= this.minLength;
        }
        if (this.maxLength) {
            err.maxLengthError = {
                given: textLength,
                maxLength: this.maxLength
            };
            valid = textLength < this.maxLength;
        }
        return valid ? null : err;
    };
    QuillEditorComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'quill-editor',
                    template: "\n<div></div>\n",
                    providers: [{
                            provide: forms_1.NG_VALUE_ACCESSOR,
                            useExisting: core_1.forwardRef(function () { return QuillEditorComponent; }),
                            multi: true
                        }, {
                            provide: forms_1.NG_VALIDATORS,
                            useExisting: core_1.forwardRef(function () { return QuillEditorComponent; }),
                            multi: true
                        }],
                    styles: ["\n    .ql-container .ql-editor {\n      min-height: 200px;\n      padding-bottom: 50px;\n    }\n  "],
                    encapsulation: core_1.ViewEncapsulation.None
                },] },
    ];
    /** @nocollapse */
    QuillEditorComponent.ctorParameters = function () { return [
        { type: core_1.ElementRef, },
    ]; };
    QuillEditorComponent.propDecorators = {
        'theme': [{ type: core_1.Input },],
        'modules': [{ type: core_1.Input },],
        'readOnly': [{ type: core_1.Input },],
        'placeholder': [{ type: core_1.Input },],
        'maxLength': [{ type: core_1.Input },],
        'minLength': [{ type: core_1.Input },],
        'formats': [{ type: core_1.Input },],
        'onEditorCreated': [{ type: core_1.Output },],
        'onContentChanged': [{ type: core_1.Output },],
    };
    return QuillEditorComponent;
}());
exports.QuillEditorComponent = QuillEditorComponent;
//# sourceMappingURL=quill-editor.component.js.map